@@ -60,14 +60,16 @@ def wait_for_network_service(netloc, check_interval, num_attempts):
 #
 
 def get_sys_path(p=None):
-    if p is None: p = sys.path
+    if p is None:
+        p = sys.path
     p = p[:]
     try:
         from distutils.util import get_platform
     except ImportError:
         return p
     p0 = ""
-    if p: p0 = p[0]
+    if p:
+        p0 = p[0]
     #
     plat = get_platform()
     plat_specifier = "%s-%s" % (plat, sys.version[:3])
